#[non_exhaustive]pub enum PathErrorKind {
EmptySegment,
SeparatorBeforeBracket,
UnterminatedBracket,
UnterminatedQuotedKey,
DanglingEscape,
ExpectedClosingBracket,
InvalidBracketSegment,
IndexOverflow,
StrayClosingBracket,
DanglingSeparator,
}Expand description
The category of a query-path syntax error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EmptySegment
A dot would create an empty mapping-key segment.
SeparatorBeforeBracket
A dot appeared immediately before a bracket segment.
UnterminatedBracket
A bracket segment has no closing bracket.
UnterminatedQuotedKey
A quoted mapping key has no closing quote.
DanglingEscape
A quoted mapping key ends with an incomplete escape.
ExpectedClosingBracket
A quoted mapping key is not followed by ].
InvalidBracketSegment
Bracket content is neither an index nor *.
IndexOverflow
A numeric sequence index does not fit in usize.
StrayClosingBracket
A closing bracket appeared outside a bracket segment.
DanglingSeparator
The path ends with a dot separator.