pub struct MappingAny(/* private fields */);Expand description
A YAML mapping with Value keys.
Unlike Mapping which only supports String keys, MappingAny allows
any Value as a key. This is useful for representing YAML mappings where
keys might be numbers, booleans, or even nested structures.
Examples
use noyalib::{MappingAny, Value};
let mut map = MappingAny::new();
map.insert(Value::from(1), Value::from("one"));
map.insert(Value::from("two"), Value::from(2));
map.insert(Value::Bool(true), Value::from("yes"));
assert_eq!(map.len(), 3);
assert_eq!(map.get(&Value::from(1)).unwrap().as_str(), Some("one"));YAML Example
This type can represent YAML like:
1: one
"two": 2
true: yes
[1, 2]: nested keyImplementations
Sourceimpl MappingAny
impl MappingAny
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty mapping with the specified capacity.
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of key-value pairs the mapping can hold without reallocating.
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more key-value pairs.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity of the mapping as much as possible.
Sourcepub fn insert(&mut self, key: Value, value: Value) -> Option<Value>
pub fn insert(&mut self, key: Value, value: Value) -> Option<Value>
Inserts a key-value pair into the mapping.
If the mapping already had this key present, the value is updated, and the old value is returned.
Sourcepub fn contains_key(&self, key: &Value) -> bool
pub fn contains_key(&self, key: &Value) -> bool
Returns true if the mapping contains the specified key.
Sourcepub fn get(&self, key: &Value) -> Option<&Value>
pub fn get(&self, key: &Value) -> Option<&Value>
Returns a reference to the value corresponding to the key.
Sourcepub fn get_mut(&mut self, key: &Value) -> Option<&mut Value>
pub fn get_mut(&mut self, key: &Value) -> Option<&mut Value>
Returns a mutable reference to the value corresponding to the key.
Sourcepub fn get_index(&self, index: usize) -> Option<(&Value, &Value)>
pub fn get_index(&self, index: usize) -> Option<(&Value, &Value)>
Returns a reference to the key-value pair at the given index.
Sourcepub fn get_index_mut(&mut self, index: usize) -> Option<(&Value, &mut Value)>
pub fn get_index_mut(&mut self, index: usize) -> Option<(&Value, &mut Value)>
Returns a mutable reference to the key-value pair at the given index.
Sourcepub fn remove(&mut self, key: &Value) -> Option<Value>
pub fn remove(&mut self, key: &Value) -> Option<Value>
Removes a key from the mapping, returning the value if the key was present.
This operation preserves the order of remaining elements.
Sourcepub fn remove_entry(&mut self, key: &Value) -> Option<(Value, Value)>
pub fn remove_entry(&mut self, key: &Value) -> Option<(Value, Value)>
Removes a key from the mapping, returning the key-value pair if present.
This operation preserves the order of remaining elements.
Sourcepub fn swap_remove(&mut self, key: &Value) -> Option<Value>
pub fn swap_remove(&mut self, key: &Value) -> Option<Value>
Removes a key by swapping it with the last element.
This is faster than remove but does not preserve order.
Sourcepub fn shift_remove(&mut self, key: &Value) -> Option<Value>
pub fn shift_remove(&mut self, key: &Value) -> Option<Value>
Removes a key by shifting all elements after it.
This preserves order but is slower than swap_remove.
Sourcepub fn entry(&mut self, key: Value) -> Entry<'_, Value, Value>
pub fn entry(&mut self, key: Value) -> Entry<'_, Value, Value>
Gets the entry for the given key for in-place manipulation.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, Value, Value> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, Value, Value> ⓘ
Returns a mutable iterator over the key-value pairs.
Sourcepub fn values_mut(&mut self) -> ValuesMut<'_, Value, Value> ⓘ
pub fn values_mut(&mut self) -> ValuesMut<'_, Value, Value> ⓘ
Returns a mutable iterator over the values.
Sourcepub fn first_mut(&mut self) -> Option<(&Value, &mut Value)>
pub fn first_mut(&mut self) -> Option<(&Value, &mut Value)>
Returns a mutable reference to the first key-value pair.
Sourcepub fn last_mut(&mut self) -> Option<(&Value, &mut Value)>
pub fn last_mut(&mut self) -> Option<(&Value, &mut Value)>
Returns a mutable reference to the last key-value pair.
Sourcepub fn pop_first(&mut self) -> Option<(Value, Value)>
pub fn pop_first(&mut self) -> Option<(Value, Value)>
Removes and returns the first key-value pair.
Sourcepub fn pop_last(&mut self) -> Option<(Value, Value)>
pub fn pop_last(&mut self) -> Option<(Value, Value)>
Removes and returns the last key-value pair.
Sourcepub fn into_inner(self) -> IndexMap<Value, Value>
pub fn into_inner(self) -> IndexMap<Value, Value>
Returns the inner IndexMap.
Sourcepub fn from_inner(map: IndexMap<Value, Value>) -> Self
pub fn from_inner(map: IndexMap<Value, Value>) -> Self
Creates a mapping from an IndexMap.
Sourcepub fn into_mapping(self) -> Option<Mapping>
pub fn into_mapping(self) -> Option<Mapping>
Converts this MappingAny to a Mapping if all keys are strings.
Returns None if any key is not a string value.
Examples
use noyalib::{Mapping, MappingAny, Value};
let mut map = MappingAny::new();
map.insert(Value::from("key1"), Value::from(1));
map.insert(Value::from("key2"), Value::from(2));
let mapping = map.into_mapping().unwrap();
assert_eq!(mapping.len(), 2);Trait Implementations
Sourceimpl Clone for MappingAny
impl Clone for MappingAny
Sourcefn clone(&self) -> MappingAny
fn clone(&self) -> MappingAny
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MappingAny
impl Debug for MappingAny
Sourceimpl Default for MappingAny
impl Default for MappingAny
Sourcefn default() -> MappingAny
fn default() -> MappingAny
Sourceimpl<'de> Deserialize<'de> for MappingAny
impl<'de> Deserialize<'de> for MappingAny
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl Display for MappingAny
impl Display for MappingAny
impl Eq for MappingAny
Sourceimpl From<IndexMap<Value, Value, FxBuildHasher>> for MappingAny
impl From<IndexMap<Value, Value, FxBuildHasher>> for MappingAny
Sourceimpl From<Mapping> for MappingAny
impl From<Mapping> for MappingAny
Sourceimpl From<MappingAny> for IndexMap<Value, Value>
Available on crate feature std only.
impl From<MappingAny> for IndexMap<Value, Value>
std only.Sourcefn from(map: MappingAny) -> Self
fn from(map: MappingAny) -> Self
Sourceimpl From<MappingAny> for IndexMap<Value, Value, FxBuildHasher>
impl From<MappingAny> for IndexMap<Value, Value, FxBuildHasher>
Sourcefn from(map: MappingAny) -> Self
fn from(map: MappingAny) -> Self
Sourceimpl FromIterator<(Value, Value)> for MappingAny
impl FromIterator<(Value, Value)> for MappingAny
Sourceimpl Hash for MappingAny
impl Hash for MappingAny
Sourceimpl Index<&Value> for MappingAny
impl Index<&Value> for MappingAny
Sourceimpl IndexMut<&Value> for MappingAny
impl IndexMut<&Value> for MappingAny
Sourceimpl IntoIterator for MappingAny
impl IntoIterator for MappingAny
Sourceimpl<'a> IntoIterator for &'a MappingAny
impl<'a> IntoIterator for &'a MappingAny
Sourceimpl<'a> IntoIterator for &'a mut MappingAny
impl<'a> IntoIterator for &'a mut MappingAny
Sourceimpl Ord for MappingAny
impl Ord for MappingAny
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for MappingAny
impl PartialEq for MappingAny
Sourceimpl PartialOrd for MappingAny
impl PartialOrd for MappingAny
Sourceimpl Serialize for MappingAny
impl Serialize for MappingAny
impl StructuralPartialEq for MappingAny
Sourceimpl Value for MappingAny
Available on crate feature sval only.
impl Value for MappingAny
sval only.Sourcefn stream<'sval, S: Stream<'sval> + ?Sized>(
&'sval self,
stream: &mut S,
) -> Result
fn stream<'sval, S: Stream<'sval> + ?Sized>( &'sval self, stream: &mut S, ) -> Result
Stream.Sourcefn to_f32(&self) -> Option<f32>
fn to_f32(&self) -> Option<f32>